@@ -26,7 +26,7 @@
 # File: install_logwatch.sh 
 # Author: Mike Tremaine [mgt /at/ stellarcore.net]
 # Maintainer: Mike Tremaine [mgt /at/ stellarcore.net]
-# $Id: install_logwatch.sh 241 2014-09-23 11:50:13Z stefjakobs $
+# $Id$
 #
 # $Log: install_logwatch.sh,v $
 # Revision 1.20  2008/05/12 22:53:28  mike
@@ -79,8 +79,8 @@ PERLEXE="/usr/bin/perl"
 MANDIR="/usr/share/man"
 
 #Command line options section
-#Currently only prefix is supported but now that the door is open other options should follow. -mgt
 ac_prev=
+systemd=0
 for ac_option
 do
    # If the previous option needs an argument, assign it.
@@ -97,8 +97,17 @@ do
          ac_prev=prefix ;;
       -prefix=* | --prefix=* | --prefi=* | --pref=* | --pre=* | --pr=* | --p=*)
          prefix=$ac_optarg ;;
+      --systemd)
+         systemd=1;;
       *)
          echo "Unknown option '$ac_option'"
+         echo "Valid options are --prefix and --systemd."
+	 echo "  Option --prefix takes one argument: a path name, which will"
+         echo "         be prepended to installation directory names"
+         echo "  Option --systemd installs the systemd files logwatch.service"
+         echo "         and logwatch.timer rather than the default 0logwatch"
+         echo "         file in /etc/cron.daily/"
+         exit
          ;;
    esac
 done
@@ -234,7 +243,7 @@ touch $CONFIGDIR/conf/override.conf
 
 #TEMP
 #Using sanity check incase someone uses /tmp.
-#The install would destory the perms on /tmp
+#The install would destroy the perms on /tmp
 if [ ! -d $TEMPDIR ]; then
    #Should this be 0700 -d $TEMPDIR ??
    install -m 0755 -d $TEMPDIR
@@ -266,8 +275,8 @@ done
 if [ -d $MANDIR/man5 ] && [ -d $MANDIR/man8 ] && [ -d $MANDIR/man1 ] && [ $HAVE_MAKEWHATIS ]; then
    install -m 0644 logwatch.8 $MANDIR/man8
    install -m 0644 logwatch.conf.5 $MANDIR/man5
-   install -m 0644 override.conf.5 $MANDIR/man5
-   install -m 0644 ignore.conf.5 $MANDIR/man5
+   ln -sf $MANDIR/man5/logwatch.conf.5  $MANDIR/man5/ignore.conf.5
+   ln -sf $MANDIR/man5/logwatch.conf.5  $MANDIR/man5/override.conf.5
    install -m 0644 postfix-logwatch.1 $MANDIR/man1
    install -m 0644 amavis-logwatch.1 $MANDIR/man1
    #OpenBSD no -s
@@ -289,12 +298,12 @@ if [ -d $MANDIR/man5 ] && [ -d $MANDIR/man8 ] && [ -d $MANDIR/man1 ] && [ $HAVE_
    fi
 else
    if [ $OS = "SunOS" ]; then
-      #Go for the safe install rather then editing man.cf
+      #Go for the safe install rather than editing man.cf
       mkdir -p $MANDIR/man1m > /dev/null 2>&1
       install -m 0644 logwatch.8 $MANDIR/man1m
       install -m 0644 logwatch.conf.5 $MANDIR/man1m
-      install -m 0644 override.conf.5 $MANDIR/man1m
-      install -m 0644 ignore.conf.5 $MANDIR/man1m
+      ln -sf $MANDIR/man1m/logwatch.conf.5  $MANDIR/man1m/ignore.conf.5
+      ln -sf $MANDIR/man1m/logwatch.conf.5  $MANDIR/man1m/override.conf.5
       install -m 0644 postfix-logwatch.1 $MANDIR/man1
       install -m 0644 amavis-logwatch.1 $MANDIR/man1
       catman -w -M $MANDIR/man1m
@@ -305,8 +314,8 @@ else
 
       install -m 0755 -d $MANDIR/man5
       install -m 0644 logwatch.conf.5 $MANDIR/man5
-      install -m 0644 override.conf.5 $MANDIR/man5
-      install -m 0644 ignore.conf.5 $MANDIR/man5
+      ln -sf $MANDIR/man5/logwatch.conf.5  $MANDIR/man5/ignore.conf.5
+      ln -sf $MANDIR/man5/logwatch.conf.5  $MANDIR/man5/override.conf.5
 
       install -m 0755 -d $MANDIR/man8
       install -m 0644 logwatch.8 $MANDIR/man8
@@ -320,13 +329,21 @@ fi
 ln -f -s $BASEDIR/scripts/logwatch.pl /usr/sbin/logwatch
 printf "Created symlink for /usr/sbin/logwatch \n"
 
-#Cron
-if [ -d /etc/cron.daily ]; then
+#Cron or Systemd timer
+if [ $systemd -eq 1 ]; then
+   install -m 0644 scheduler/logwatch.service /lib/systemd/system/logwatch.service
+   install -m 0644 scheduler/logwatch.timer /lib/systemd/system/logwatch.timer
+   if [ ! -e /lib/systemd/system/multi-user.target.wants ]; then
+      install -m 0755 -d /lib/systemd/system/multi-user.target.wants
+   fi
+   ln -sf ../logwatch.timer /lib/systemd/system/multi-user.target.wants/logwatch.timer
+   printf "Created and enabled systemd logwatch.timer"
+elif [ -d /etc/cron.daily ]; then
    rm -f /etc/cron.daily/0logwatch
-   install -m 0755 logwatch.cron /etc/cron.daily/0logwatch
+   install -m 0755 scheduler/logwatch.cron /etc/cron.daily/0logwatch
    printf "Created /etc/cron.daily/0logwatch \n" 
 else
-   install -m 0744 logwatch.cron $CONFIGDIR/logwatch.cron
+   install -m 0744 scheduler/logwatch.cron $CONFIGDIR/logwatch.cron
    printf "################ README ####################.\n"
    printf "You need to setup your cron job for logwatch.\n"
    printf "A sample script is included see $CONFIGDIR/logwatch.cron. \n"
