@@ -3,24 +3,28 @@ use strict;
 ##########################################################################
 ##########################################################################
 # Most current version can always be found at:
-# ftp://ftp.logwatch.org/pub/linux (tarball)
-# ftp://ftp.logwatch.org/pub/redhat/RPMS (RPMs)
+#	https://sourceforge.net/p/logwatch/git/ci/master/tree/
+# A tarball, perhaps not as current as the version listed above, can be
+# found at (after a slight delay):
+#	https://sourceforge.net/projects/logwatch/files/latest/download
 
 ########################################################
 # Specify version and build-date:
-my $Version = '7.4.3';
-my $VDate = '04/27/16';
+my $Version = '7.5.2';
+my $VDate = '07/22/19';
 
 #######################################################
-# Logwatch was written and is maintained by:
+# Logwatch was originally written by:
 #    Kirk Bauer <kirk@kaybee.org>
 #
 # Unless otherwise specified, Logwatch and all bundled filter scripts
 # are Copyright (c) Kirk Bauer and covered under the included MIT/X
 # Consortium license.
 #
-# Please send all comments, suggestions, bug reports,
-#    etc, to logwatch@logwatch.org.
+# Please file all bug reports, patches, and feature requests under:
+#	https://sourceforge.net/p/logwatch/_list/tickets
+# Help requests and disccusion can be filed under:
+#	https://sourceforge.net/p/logwatch/discussion/
 #
 ########################################################
 
@@ -979,7 +983,8 @@ sub getInt {
 ######################################################################
 sub CleanVars {
    foreach (keys %Config) {
-      unless (defined $Config{$_} and $_ eq "hostname") {
+      unless (defined $Config{$_} and
+	($_ =~ /^(hostname|filename|mailto|logdir|hostlimit)$/ )) {
          $Config{$_} = getInt($Config{$_});
       }
    }
